==> bijiben_3.8.4.orig.tar.xz: bijiben-3.8.4/src/bjb-selection-toolbar.h <==
/* bjb-selection-toolbar.h
 * Copyright © 2012, 2013 Red Hat, Inc.
 * Copyright © 2013 Pierre-Yves LUYTEN <py@luyten.fr>
 *
 * bijiben is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * bijiben is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BJB_SELECTION_TOOLBAR_H
#define BJB_SELECTION_TOOLBAR_H

#include <libgd/gd.h>

G_BEGIN_DECLS

#define BJB_TYPE_SELECTION_TOOLBAR (bjb_selection_toolbar_get_type ())

#define BJB_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbar))

#define BJB_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarClass))

#define BJB_IS_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BJB_TYPE_SELECTION_TOOLBAR))

#define BJB_IS_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BJB_TYPE_SELECTION_TOOLBAR))

#define BJB_SELECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarClass))

typedef struct _BjbSelectionToolbar        BjbSelectionToolbar;
typedef struct _BjbSelectionToolbarClass   BjbSelectionToolbarClass;
typedef struct _BjbSelectionToolbarPrivate BjbSelectionToolbarPrivate;

struct _BjbSelectionToolbar
{
  GtkToolbar parent_instance;
  BjbSelectionToolbarPrivate *priv;
};

struct _BjbSelectionToolbarClass
{
  GtkToolbarClass parent_class;
};

GType bjb_selection_toolbar_get_type (void) G_GNUC_CONST;

BjbSelectionToolbar * bjb_selection_toolbar_new (GdMainView   *selection,
                                                 BjbMainView  *bjb_main_view);

G_END_DECLS

#endif /* BJB_SELECTION_TOOLBAR_H */

==> bijiben_3.18.2.orig.tar.xz: bijiben-3.18.2/src/bjb-selection-toolbar.h <==
/* bjb-selection-toolbar.h
 * Copyright © 2012, 2013 Red Hat, Inc.
 * Copyright © 2013 Pierre-Yves LUYTEN <py@luyten.fr>
 *
 * bijiben is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * bijiben is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BJB_SELECTION_TOOLBAR_H
#define BJB_SELECTION_TOOLBAR_H

#include <libgd/gd.h>

G_BEGIN_DECLS

#define BJB_TYPE_SELECTION_TOOLBAR (bjb_selection_toolbar_get_type ())

#define BJB_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbar))

#define BJB_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarClass))

#define BJB_IS_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BJB_TYPE_SELECTION_TOOLBAR))

#define BJB_IS_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BJB_TYPE_SELECTION_TOOLBAR))

#define BJB_SELECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarClass))

typedef struct _BjbSelectionToolbar        BjbSelectionToolbar;
typedef struct _BjbSelectionToolbarClass   BjbSelectionToolbarClass;
typedef struct _BjbSelectionToolbarPrivate BjbSelectionToolbarPrivate;

struct _BjbSelectionToolbar
{
  GtkRevealer parent_instance;
  BjbSelectionToolbarPrivate *priv;
};

struct _BjbSelectionToolbarClass
{
  GtkRevealerClass parent_class;
};

GType bjb_selection_toolbar_get_type (void) G_GNUC_CONST;

BjbSelectionToolbar * bjb_selection_toolbar_new (GdMainView   *selection,
                                                 BjbMainView  *bjb_main_view);

G_END_DECLS

#endif /* BJB_SELECTION_TOOLBAR_H */
